summaryrefslogtreecommitdiffstats
path: root/kpilot/lib/pilotLocalDatabase.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/lib/pilotLocalDatabase.h')
-rw-r--r--kpilot/lib/pilotLocalDatabase.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/kpilot/lib/pilotLocalDatabase.h b/kpilot/lib/pilotLocalDatabase.h
index c33455800..e5d11a63a 100644
--- a/kpilot/lib/pilotLocalDatabase.h
+++ b/kpilot/lib/pilotLocalDatabase.h
@@ -54,14 +54,14 @@ public:
* the database cannot be found, no database is opened. It can then be
* created explicitly at the specified location.
*/
- PilotLocalDatabase( const QString& path,
- const QString& name, bool useDefaultPath=true);
+ PilotLocalDatabase( const TQString& path,
+ const TQString& name, bool useDefaultPath=true);
/**
* Opens the local database. This is primarily for testing
* purposes; only tries the given path.
*/
- PilotLocalDatabase(const QString &name);
+ PilotLocalDatabase(const TQString &name);
virtual ~PilotLocalDatabase();
@@ -85,8 +85,8 @@ public:
virtual int writeAppBlock(unsigned char* buffer, int len);
// returns the number of records in the database, 0 if not open
virtual unsigned int recordCount() const;
- // Returns a QValueList of all record ids in the database.
- virtual QValueList<recordid_t> idList();
+ // Returns a TQValueList of all record ids in the database.
+ virtual TQValueList<recordid_t> idList();
// Reads a record from database by id, returns record
virtual PilotRecord* readRecordById(recordid_t id);
// Reads a record from database, returns the record
@@ -134,14 +134,14 @@ public:
/** Return the name of the database (as it would be on the handheld). */
- QString getDBName() const { return fDBName; }
+ TQString getDBName() const { return fDBName; }
/**
* Returns the full path of the current database, based on
* the path and dbname passed to the constructor, and including
* the .pdb extension.
*/
- virtual QString dbPathName() const;
+ virtual TQString dbPathName() const;
/**
* Accessor functions for the application info block.
@@ -166,7 +166,7 @@ public:
* library doesn't provide a cheap way of getting this
* information.
*/
- static bool infoFromFile( const QString &path, DBInfo *d );
+ static bool infoFromFile( const TQString &path, DBInfo *d );
protected:
// Changes any forward slashes to underscores
@@ -176,7 +176,7 @@ protected:
private:
struct DBInfo fDBInfo;
- QString fPathName,fDBName;
+ TQString fPathName,fDBName;
char* fAppInfo;
size_t fAppLen;
@@ -189,13 +189,13 @@ public:
* preferred one, too) try this path first before the default path.
* Set statically so it's shared for all local databases.
*/
- static void setDBPath(const QString &);
+ static void setDBPath(const TQString &);
/**
* Accessor for the extra search path.
*/
- static const QString &getDBPath() { return *fPathBase; } ;
+ static const TQString &getDBPath() { return *fPathBase; } ;
private:
- static QString *fPathBase;
+ static TQString *fPathBase;
};
#endif